aboutsummaryrefslogtreecommitdiff
path: root/Minecraft.Client/Common/Network/GameNetworkManager.h
diff options
context:
space:
mode:
authorqwasdrizzel <145519042+qwasdrizzel@users.noreply.github.com>2026-03-16 21:44:26 -0500
committerGitHub <noreply@github.com>2026-03-16 21:44:26 -0500
commitce739f6045ec72127491286ea3f3f21e537c1b55 (patch)
treef33bd42a47c1b4a7b2153a7fb77127ee3b407db9 /Minecraft.Client/Common/Network/GameNetworkManager.h
parent255a18fe8e9b57377975f82e2b227afe2a12eda0 (diff)
parent5a59f5d146b43811dde6a5a0245ee9875d7b5cd1 (diff)
Merge branch 'smartcmd:main' into main
Diffstat (limited to 'Minecraft.Client/Common/Network/GameNetworkManager.h')
-rw-r--r--Minecraft.Client/Common/Network/GameNetworkManager.h26
1 files changed, 13 insertions, 13 deletions
diff --git a/Minecraft.Client/Common/Network/GameNetworkManager.h b/Minecraft.Client/Common/Network/GameNetworkManager.h
index bb7633c2..3357b3cd 100644
--- a/Minecraft.Client/Common/Network/GameNetworkManager.h
+++ b/Minecraft.Client/Common/Network/GameNetworkManager.h
@@ -100,26 +100,26 @@ public:
void SetSessionsUpdatedCallback( void (*SessionsUpdatedCallback)(LPVOID pParam), LPVOID pSearchParam );
void GetFullFriendSessionInfo( FriendSessionInfo *foundSession, void (* FriendSessionUpdatedFn)(bool success, void *pParam), void *pParam );
void ForceFriendsSessionRefresh();
-
+
// Session joining and leaving
bool JoinGameFromInviteInfo( int userIndex, int userMask, const INVITE_INFO *pInviteInfo);
- eJoinGameResult JoinGame(FriendSessionInfo *searchResult, int localUsersMask);
+ eJoinGameResult JoinGame(FriendSessionInfo *searchResult, int localUsersMask);
static void CancelJoinGame(LPVOID lpParam); // Not part of the shared interface
bool LeaveGame(bool bMigrateHost);
static int JoinFromInvite_SignInReturned(void *pParam,bool bContinue, int iPad);
- void UpdateAndSetGameSessionData(INetworkPlayer *pNetworkPlayerLeaving = NULL);
+ void UpdateAndSetGameSessionData(INetworkPlayer *pNetworkPlayerLeaving = nullptr);
void SendInviteGUI(int iPad);
void ResetLeavingGame();
// Threads
-
+
bool IsNetworkThreadRunning();
static int RunNetworkGameThreadProc( void* lpParameter );
static int ServerThreadProc( void* lpParameter );
static int ExitAndJoinFromInviteThreadProc( void* lpParam );
-#if (defined __PS3__) || (defined __ORBIS__) || (defined __PSVITA__)
+#if (defined __PS3__) || (defined __ORBIS__) || (defined __PSVITA__)
static int MustSignInReturned_0(void *pParam,int iPad,C4JStorage::EMessageResult result);
static int PSNSignInReturned_0(void* pParam, bool bContinue, int iPad);
@@ -130,24 +130,24 @@ public:
static void _LeaveGame();
static int ChangeSessionTypeThreadProc( void* lpParam );
- // System flags
+ // System flags
void SystemFlagSet(INetworkPlayer *pNetworkPlayer, int index);
bool SystemFlagGet(INetworkPlayer *pNetworkPlayer, int index);
// Events
- void ServerReadyCreate(bool create); // Create the signal (or set to NULL)
+ void ServerReadyCreate(bool create); // Create the signal (or set to nullptr)
void ServerReady(); // Signal that we are ready
void ServerReadyWait(); // Wait for the signal
void ServerReadyDestroy(); // Destroy signal
- bool ServerReadyValid(); // Is non-NULL
+ bool ServerReadyValid(); // Is non-nullptr
void ServerStoppedCreate(bool create); // Create the signal
void ServerStopped(); // Signal that we are ready
- void ServerStoppedWait(); // Wait for the signal
- void ServerStoppedDestroy(); // Destroy signal
- bool ServerStoppedValid(); // Is non-NULL
+ void ServerStoppedWait(); // Wait for the signal
+ void ServerStoppedDestroy(); // Destroy signal
+ bool ServerStoppedValid(); // Is non-nullptr
#ifdef __PSVITA__
static bool usingAdhocMode();
@@ -164,9 +164,9 @@ public:
// Used for debugging output
static const int messageQueue_length = 512;
- static __int64 messageQueue[messageQueue_length];
+ static int64_t messageQueue[messageQueue_length];
static const int byteQueue_length = 512;
- static __int64 byteQueue[byteQueue_length];
+ static int64_t byteQueue[byteQueue_length];
static int messageQueuePos;
// Methods called from PlatformNetworkManager